@echo off
setlocal EnableDelayedExpansion

set TALEND_HOME=C:\Talend\8.0.1
set PROD_VER=8.0.1

rem Before running this script, check and set the following variables defined above these instructions:
rem  TALEND_HOME - Talend home folder. For example, "C:\Talend\8.0.1".
rem  PROD_VER    - Product version. For example, "8.0.1".

rem Supported Talend versions: 7.3 and 8.0.
rem Supported Java versions: 8, 11, and 17. Java 17 is only supported for Talend 8.0.1 R2023-10 or above.

rem This script can be called after the Java version update.
rem It will reset the hard-coded path to Java to the new value.

rem *** IMPORTANT ***
rem This script should be called in the console with Administrator privileges.
rem It should be called from the 'utils' folder of your Talend installation.

rem Recommended procedure for updating the Java settings for Talend applications and services:
rem 1. Install the new Java version without removing the old one yet.
rem 2. Stop all Talend services from the Microsoft Management Console 'Services' snap-in. The last services to be stopped should be Talend Administration Center, Talend Identity and Access Management, then Kafka, ZooKeeper, and MongoDB.
rem 3. Update the JAVA_HOME and PATH variables with the new Java home in System -> Advanced System Settings -> Environment Variables.
rem 4. Start a new console window with Administrator privileges.
rem 4a. Verify that JAVA_HOME and PATH are set correcly by using the "set" or "echo" commands.
rem 5. Change the working folder to <TALEND_HOME>/utils.
rem 6. Check the TALEND_HOME and PROD_VER variables at the beginning of this file and update them if needed.
rem 7. Run this update_java.bat file.
rem 8. Start all Talend services from the Microsoft Management Console or reboot the host.
rem 9. (Optional) After all services are started successfully, you can remove the old Java version if it is not used by other software.

rem === Execution starts here ===

rem Check that the current location is %TALEND_HOME%\utils
for /f %%i in ('cd') do set PWD=%%i

rem Check Administrator privileges
net session >nul 2>&1
if %errorlevel% neq 0 (
  echo Error: Administrator privileges are required.
  echo Re-start a command line window with Administrator privileges
  echo and then re-run this file.
  goto :eof
)

if not exist "%TALEND_HOME%\uninstall.exe" (
  echo Error: Talend installation at %TALEND_HOME% seems to be broken.
  echo Cannot proceed.
  goto :eof
)

if not "%PWD%" == "%TALEND_HOME%\utils" (
  echo Error: this script must be run from %TALEND_HOME%\utils folder.
  echo Cannot proceed.
  goto :eof
)

if not exist "%TALEND_HOME%\utils\sed.exe" (
  echo Error: cannot find sed.exe. Download this file from the Talend documentation and put it in %TALEND_HOME%\utils.
  goto :eof
)

rem Check that JAVA_HOME does not contain double quotes (")
set JJJ1=%JAVA_HOME:"=*%
set JJJ2=%JAVA_HOME:"=+%
if not "%JJJ1%" == "%JJJ2%" (
  echo Error: JAVA_HOME variable contains double quotes symbols ("). Remove them before continuing.
  echo WRONG: set JAVA_HOME="C:\Program Files\Java\jdk"
  echo RIGHT: set JAVA_HOME=C:\Program Files\Java\jdk
  goto :eof
)

if not exist "%JAVA_HOME%\bin\java.exe" (
  echo Error: JAVA_HOME is set incorrectly.
  echo Cannot proceed.
  echo JAVA_HOME: %JAVA_HOME%
  echo Please set JAVA_HOME to a Java home location and restart this script.
  goto :eof
)

if not exist "%JAVA_HOME%\bin\server\jvm.dll" (
  echo Error: JAVA_HOME is set incorrectly.
  echo JAVA_HOME: %JAVA_HOME%
  echo It is expected to have jvm.dll under path bin\server at JAVA_HOME.
  echo Cannot proceed.
  goto :eof
)

rem Extract Java version: special processing for Java 11 / Java 17
echo s/^^[^^"]*"// >temp1.txt
echo s/^".*// >temp2.txt
"%JAVA_HOME%\bin\java" -version 2>java_ver.txt
type java_ver.txt | findstr "version" | sed -f temp1.txt | sed -f temp2.txt >java_ver1.txt
set /p JAVA_VERSION=<java_ver1.txt
del /q temp1.txt temp2.txt java_ver.txt java_ver1.txt
if "%JAVA_VERSION%" == "" (
  echo Cannot parse Java version for Java installation at %JAVA_HOME%.
  echo Cannot proceed.
  goto :eof
)

rem Reset the flag to stop Java upgrade - this can be only if Java 17 is selected but Talend is older than 8.0.1 R2023-10
set StopJavaUpgrade=

rem in "getJava11" procedure, the script may set one of these two variables:
rem    "Java11" - will be set to non-empty value if target Java is Java 11
rem    "Java17" - will be set to non-empty value if target Java is Java 17
call :getJava11

rem Check the compatibility: Java 11 is supported only for 7.3.1 and 8.0.1
if not "%Java11%" == "" (
  if "%PROD_VER:~0,3%" == "7.3" goto :ok1
  if "%PROD_VER:~0,3%" == "8.0" goto :ok1
  echo Error: Java 11 is not supported for Talend %PROD_VER%
  goto :eof
)

rem Check the compatibility for Java 17. It is supported only for 8.0.1 R2023-10 release.
if not "%Java17%" == "" (
  call :checkJava17tomcat
  call :checkJava17dataprep
  call :checkJava17runtime
  del /q "%TALEND_HOME%\utils\out*.txt" 2>nul
  if defined StopJavaUpgrade goto :eof
)

:ok1

echo.
echo Updating Talend services to use Java version %JAVA_VERSION% located at %JAVA_HOME%...
echo.

cd "%TALEND_HOME%\utils"

call :checkService tdqp-tomcat-%PROD_VER% TDQP_SERV
if not "%Java11%%Java17%" == "" (
  if not "%TDQP_SERV%" == "" (
    echo ************
    echo Warning: Talend Data Quality Portal service will NOT be updated to use Java 11
    echo ************
  )
)

if not "%Java17%" == "" (
  call :checkService talend-mdm-%PROD_VER% MDM_SERV
  call :checkService talend-logserver-collector-%PROD_VER% LOG_SERV
  if not "!MDM_SERV!" == "" (
    echo ************
    echo Warning: Talend MDM service doesn't support Java 17 will not be updated to use Java 17.
    echo ************
  )
  if not "!LOG_SERV!" == "" (
    echo ************
    echo Warning: Talend LogServer services don't support Java 17 will not be updated to use Java 17.
    echo ************
  )
)

rem Check that Talend services are not running
set TAL_SERV=
sc query | findstr /C:"talend-" /I >1.txt
sc query | findstr /C:"Talend " >>1.txt
sc query | findstr /C:"tdqp-" >>1.txt
set /p TAL_SERV=<1.txt
del /q 1.txt

if not "%TAL_SERV%" == "" (
  echo ERROR: some Talend services are running.
  echo        Stop them manually before re-running this script.
  goto :eof
)

cd "%TALEND_HOME%\utils"

rem For sed, the Windows path must contain double-slashes.
rem Three variables are needed: with doubled backslashes, with backslashes converted to forward slashes,
rem   and with full path to java.exe.
echo %JAVA_HOME%\bin\java.exe| sed s#\\#\\\\#g >1.txt
set /p JAVA_HOME_MOD=<1.txt
echo %JAVA_HOME%\bin\java.exe| sed s#\\#/#g >1.txt
set /p JAVA_HOME_MOD2=<1.txt
echo %JAVA_HOME%| sed s#\\#\\\\#g >1.txt
set /p JAVA_HOME_MOD3=<1.txt
del /q 1.txt

rem Before the script starts to modify services, one precaution should be checked. This is only relevant for versions older than 8.0.1.
rem If Talend Data Quality Portal is installed on Talend Administration Center, this dependency must be removed.
rem Otherwise the script would not be able to delete the Talend Data Quality Portal database service, which must be removed before reinstallation.
if exist "%TALEND_HOME%\tdqp\TalendServicesDB\wrapper.jar" (
  if not exist "%TALEND_HOME%\tdqp\TalendServicesTomcat\wrapper.jar" (
    if exist "%TALEND_HOME%\tac\apache-tomcat\bin\catalina.bat" (
      sc config talend-tac-%PROD_VER% depend= ""
    )
  )
)

rem First the script processes the services that are based on TalendServices (YAJSW project)
for %%p in (bonita cmdline jobserver tdqp) do (
  if %%p == tdqp (
    if "%Java11%%Java17%" == "" (
      call ::ProcFolder %%p\TalendServicesDB
      call ::ProcFolder %%p\TalendServicesTomcat
    )
  ) else (
    call ::ProcFolder %%p\TalendServices
  )
)

rem Then the script processes Apache native services: TAC and MDM
for %%p in (tac iam mdm tds dq_dict) do (
  call ::ProcApache %%p
)

rem Additionally for TAC: when upgraded to Java 17, we need to ensure that "--add-opens" directives are added to JvmOption
if not "%Java17%" == "" (
  if exist "%TALEND_HOME%\tac\apache-tomcat\bin\tomcat9.exe" (
    cd "%TALEND_HOME%\utils"
    "%TALEND_HOME%\tac\apache-tomcat\bin\tomcat9.exe" //PS//talend-tac-%PROD_VER% 2>&1 | findstr /C:"--add-opens=" >out.txt
	set /p TAC_ADD_OPENS=<out.txt
	del /q out.txt
	if "!TAC_ADD_OPENS!" == "" (
	  "%TALEND_HOME%\tac\apache-tomcat\bin\tomcat9.exe" //US//talend-tac-%PROD_VER% ++JvmOptions="--add-opens=java.base/sun.security.x509=ALL-UNNAMED"
	  "%TALEND_HOME%\tac\apache-tomcat\bin\tomcat9.exe" //US//talend-tac-%PROD_VER% ++JvmOptions="--add-opens=java.base/sun.security.pkcs=ALL-UNNAMED"
	)
  )
)

rem Updating JobServer agent scripts
if exist "%TALEND_HOME%\jobserver\agent\start_rs.bat" (
  call ::UpdateJobserver
)

cd "%TALEND_HOME%\utils"

rem Finally re-apply the service dependency if Talend DQ Portal is installed on TAC
if exist "%TALEND_HOME%\tdqp\TalendServicesDB\wrapper.jar" (
  if not exist "%TALEND_HOME%\tdqp\TalendServicesTomcat\wrapper.jar" (
    sc config talend-tac-%PROD_VER% depend= tdqp-database-%PROD_VER%
  )
)

if exist "%TALEND_HOME%\runtime\etc\talend-runtime-%PROD_VER%-wrapper.conf" (
  call ::ProcRuntime
)

rem Update Zookeeper and Kafka
if exist "%TALEND_HOME%\kafka\bin\windows\kafka-run-class.bat" (
  call ::ProcKafka
)

rem Update LogServer
if exist "%TALEND_HOME%\logserv\start_logserver.bat" (
  if "%Java17%" == "" (
    call ::ProcElasticSearch
    call ::ProcLogStash
  )
)
cd "%TALEND_HOME%\utils"

rem Clean up additional temporary variables
set JAVA_HOME_MOD=
set JAVA_HOME_MOD2=
set JAVA_HOME_MOD3=

echo.
echo Java version update is complete.
echo.

if not "%Java11%%Java17%" == "" (
  if not "%TDQP_SERV%" == "" (
    echo ************
    echo Warning: Talend DQ Portal service was not updated to use Java 11.
    echo ************
  )
)

if not "%Java17%" == "" (
  if not "%MDM_SERV%" == "" (
    echo ************
    echo Warning:  Talend MDM service was not updated for Java 17 and it remains on the old Java version.
    echo ************
  )
  if not "%LOG_SERV%" == "" (
    echo ************
    echo Warning: Talend LogServer service was not updated for Java 17 and it remains on the old Java version.
    echo ************
  )
)

goto :eof

rem ProcessFolder - main subroutine for processing components driven with TalendServices wrapper
:ProcFolder
set folder=%1
if not "%Java17%" == "" goto :eof
if not exist "%TALEND_HOME%\%folder%\bat\setenv.bat" goto :eof
echo Processing folder %folder%

cd "%TALEND_HOME%\%folder%\bat"
call uninstallService.bat
cd "%TALEND_HOME%"

if exist %folder%\bat\setenv.bat (
  call ::SubstSetEnv %folder%\bat\setenv.bat
)

if exist %folder%\conf\wrapper.conf (
  call ::SubstWrapConf %folder%\conf\wrapper.conf
)

cd "%TALEND_HOME%\%folder%\bat"
call installService.bat
cd "%TALEND_HOME%"

goto :eof

rem Substitute setenv.bat in wrapper 'bat' folder
:SubstSetEnv
set file=%1
if exist %file%.new del /q /f %file%.new
"%TALEND_HOME%\utils\sed" "s/set java_exe=.*/set java_exe=\"%JAVA_HOME_MOD%\"/" %file% > %file%.new
call ::RenameFile %file% %file%.new
goto :eof

rem Substitute wrapper.conf in 'conf' folder
:SubstWrapConf
set file=%1
if exist %file%.new (
  del /q /f %file%.new
)
"%TALEND_HOME%\utils\sed" "s#wrapper.java.command=.*#wrapper.java.command=%JAVA_HOME_MOD2%#" %file% > %file%.new
call ::RenameFile %file% %file%.new
"%TALEND_HOME%\utils\sed" "s#wrapper.java.command = .*#wrapper.java.command = %JAVA_HOME_MOD2%#" %file% > %file%.new
call ::RenameFile %file% %file%.new
goto :eof

rem RenameFile performs renaming new -> old only if new file exists and has not a zero size
:RenameFile
if not exist %2 goto :eof
if %~z2 equ 0 (
  echo ERROR during pattern substitution, cannot process file %1
  del /q /f %2
  goto :eof
)
rem All is OK, proceed with renaming
del /q /f %1
rename %2 %~nx1
goto :eof

:ProcApache
set folder=%1
set service=%1
if not "%Java17%" == "" (
  if "%folder%" == "mdm" goto :eof
)
set TOMCAT_BIN=tomcat8.exe
if exist "%TALEND_HOME%\%folder%\apache-tomcat\bin\tomcat9.exe" set TOMCAT_BIN=tomcat9.exe
if not exist "%TALEND_HOME%\%folder%\apache-tomcat\bin\%TOMCAT_BIN%" goto :eof
if "%folder%" == "dq_dict" set service=dqdict
cd %TALEND_HOME%\%folder%\apache-tomcat\bin
echo Updating apache tomcat service parameters for %folder%
%TOMCAT_BIN% //US//talend-%service%-%PROD_VER% --Jvm="%JAVA_HOME%\bin\server\jvm.dll"
goto :eof

:ProcRuntime
set file=%TALEND_HOME%\runtime\etc\talend-runtime-%PROD_VER%-wrapper.conf
if not exist "%file%" goto :eof
echo Processing Runtime component
"%TALEND_HOME%\utils\sed" "s#set.default.JAVA_HOME=.*#set.default.JAVA_HOME=%JAVA_HOME_MOD3%#" "%file%" > "%file%.new"
call ::RenameFile "%file%" "%file%.new"

if "%Java11%%Java17%" == "" goto :eof
set JAVA_ENDORSED=
type "%file%" | findstr /b /l "wrapper.java.additional.1=-Djava.endorsed.dirs=">java_endorsed.txt
if %ERRORLEVEL% EQU 0 set JAVA_ENDORSED=1
del /q java_endorsed.txt
if "%JAVA_ENDORSED%" == "" goto :eof

rem OK, now we are with Java 11 or Java 17 and we have Endorsed dirs option, we must remove it by commenting it out.
cd "%TALEND_HOME%\runtime\etc"
"%TALEND_HOME%\utils\sed.exe" -e "s/wrapper\.java\.additional\.1=/#wrapper.java.additional.1=/" talend-runtime-%PROD_VER%-wrapper.conf >11.txt
call ::RenameFile talend-runtime-%PROD_VER%-wrapper.conf 11.txt
"%TALEND_HOME%\utils\sed.exe" -e "s/wrapper\.java\.additional\.2=/#wrapper.java.additional.2=/" talend-runtime-%PROD_VER%-wrapper.conf >11.txt
call ::RenameFile talend-runtime-%PROD_VER%-wrapper.conf 11.txt
for /l %%i in (3,1,20) do call ::ProcessRtLine %%i
goto :eof

:ProcessRtLine
set line=%1
set /a "line_new = line - 2"
type talend-runtime-%PROD_VER%-wrapper.conf | findstr /b /l "wrapper.java.additional.%line%=" >11.txt
set /p RtLineExists=<11.txt
del /q 11.txt
if "%RtLineExists%" == "" goto :eof

"%TALEND_HOME%\utils\sed.exe" -e "s/^wrapper\.java\.additional\.%line%=/wrapper.java.additional.%line_new%=/" talend-runtime-%PROD_VER%-wrapper.conf >11.txt
call ::RenameFile talend-runtime-%PROD_VER%-wrapper.conf 11.txt

goto :eof

:ProcKafka
if "%PROD_VER:~0,3%" == "8.0" (
  echo %TALEND_HOME%| "%TALEND_HOME%\utils\sed" "s#\\#/#g" > "%TALEND_HOME%\utils\1.txt"
  set /p TALEND_HOME2=<"%TALEND_HOME%\utils\1.txt"
  del /q "%TALEND_HOME%\utils\1.txt"
  "%TALEND_HOME%\utils\nssm.exe" set talend-zookeeper-%PROD_VER% AppEnvironmentExtra "JAVA_HOME=%JAVA_HOME%" "KAFKA_OPTS=-Djava.security.auth.login.config=\"!TALEND_HOME2!/kafka/config/jaas_config.conf\""
  "%TALEND_HOME%\utils\nssm.exe" set talend-kafka-%PROD_VER% AppEnvironmentExtra "JAVA_HOME=%JAVA_HOME%" "KAFKA_OPTS=-Djava.security.auth.login.config=\"!TALEND_HOME2!/kafka/config/jaas_config.conf\""
) else (
  "%TALEND_HOME%\utils\nssm.exe" set talend-zookeeper-%PROD_VER% AppEnvironmentExtra "JAVA_HOME=%JAVA_HOME%"
  "%TALEND_HOME%\utils\nssm.exe" set talend-kafka-%PROD_VER% AppEnvironmentExtra "JAVA_HOME=%JAVA_HOME%"
)
goto :eof

:ProcElasticSearch
rem Getting ES root folder name. It can be different in different versions.
cd "%TALEND_HOME%\logserv"
dir /b | findstr "elasticsearch" >"%TALEND_HOME%\utils\es_name.txt"
set /p ES_NAME=<"%TALEND_HOME%\utils\es_name.txt"
del /q "%TALEND_HOME%\utils\es_name.txt"
if "%ES_NAME%" == "" (
  echo "Error: cannot get ElasticSearch folder name "
  echo "Cannot process ElasticSearch Java update"
  goto :eof
)
if not exist "%TALEND_HOME%\logserv\%ES_NAME%\bin\elasticsearch-service-x64.exe" (
  echo "Error: cannot update ElasticSearch Java parameters because executable elasticsearch-service-x64.exe is missing"
  goto :eof
)
"%TALEND_HOME%\logserv\%ES_NAME%\bin\elasticsearch-service-x64.exe" //US//talend-logserver-search-%PROD_VER% --Jvm="%JAVA_HOME%\bin\server\jvm.dll"

rem Now updating Procrun Registry parameters, only if the update is from Java 8 to Java 11.
if "%Java11%" == "" (
  goto :eof
)

cd "%TALEND_HOME%\utils"

reg query "HKLM\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\talend-logserver-search-%PROD_VER%\Parameters\Java" /v Options |findstr "Options" | sed "s/^.* -X/-X/" >es-opts.txt
set /p ES_OPTS=<es-opts.txt
if "%ES_OPTS%" == "" (
  echo Warning: cannot receive ElasticSearch startup options from the registry
  echo Cannot update ElasticSearch startup options
  goto :eof
)

type es-opts.txt | findstr /c:"-XX:+PrintTenuringDistribution" >es-opts-tmp.txt
set /p ES_OPTS_TMP=<es-opts-tmp.txt
del /q es-opts-tmp.txt
rem Skip further processing if Options are already in the needed state
if "%ES_OPTS_TMP%" == "" (
  del /q es-opts.txt
  goto :eof
)

rem Update these settings only if they are still present there
sed -e "s/-XX:+PrintGCDateStamps\\0//" -e "s/-XX:+PrintTenuringDistribution\\0//" -e "s/-XX:+PrintGCApplicationStoppedTime\\0//" -e "s/-XX:+UseGCLogFileRotation\\0//" -e "s/-XX:NumberOfGCLogFiles=32\\0//" -e "s/-XX:GCLogFileSize=64m\\0//" es-opts.txt >es-opts.txt.new
call ::RenameFile es-opts.txt es-opts.txt.new
set /p ES_OPTS=<es-opts.txt
del /q es-opts.txt
if "%ES_OPTS%" == "" (
  echo Error: cannot update ElasticSearch options
  goto :eof
)
reg add "HKLM\SOFTWARE\WOW6432Node\Apache Software Foundation\Procrun 2.0\talend-logserver-search-%PROD_VER%\Parameters\Java" /v Options /t REG_MULTI_SZ /f /d "%ES_OPTS%"

goto :eof

rem This utility procedure will set the Java11 variable to non-empty value only if we are now on Java11.
rem This is needed by ElasticSearch and Runtime services which need extra processing if upgrading from Java 8 to Java 11.
rem Addition: it will also set Java17 variable to non-empty value when Java is Java17
:getJava11
set Java11=
set Java17=
cd "%TALEND_HOME%\utils"
echo %JAVA_VERSION% | findstr /b /c:"11." >java11.txt
set /p Java11=<java11.txt
del /q java11.txt
echo %JAVA_VERSION% | findstr /b /c:"17." >java17.txt
set /p Java17=<java17.txt
del /q java17.txt
goto :eof

:ProcLogStash
rem Getting LogStash root folder name which can be different in different Talend versions.
cd "%TALEND_HOME%\logserv"
dir /b | findstr /r /c:"logstash-[0-9]" >"%TALEND_HOME%\utils\ls_name.txt"
set /p LS_NAME=<"%TALEND_HOME%\utils\ls_name.txt"
del /q "%TALEND_HOME%\utils\ls_name.txt"
if "%LS_NAME%" == "" (
  echo "Error: cannot get LogStash folder name "
  echo "Cannot process LogStash Java update"
  goto :eof
)
if not exist "%TALEND_HOME%\logserv\%LS_NAME%\bin\logstash.bat" (
  echo "Error: cannot update LogStash Java parameters because script logstash.bat is missing"
  goto :eof
)

cd "%TALEND_HOME%\logserv\%LS_NAME%\bin"
"%TALEND_HOME%\utils\sed" -e "s/set JAVA_HOME=.*/set JAVA_HOME=%JAVA_HOME_MOD3%/" logstash.bat >logstash.bat.new
call ::RenameFile logstash.bat logstash.bat.new
goto :eof

rem This procedure is used in compatibility check for Java 17. In this case, used Tomcat must be version 9.0.82 or above.
:checkJava17tomcat
for %%p in (tac iam mdm tds dq_dict) do (
  if exist "%TALEND_HOME%\%%p\apache-tomcat\RELEASE-NOTES" (
    call ::checkJava17tomcat2 %%p
    del /q "%TALEND_HOME%\utils\out*.txt" 2>nul
  )
)
goto :eof

:checkJava17tomcat2
set "file=%TALEND_HOME%\%1\apache-tomcat\RELEASE-NOTES"
set tomcat_ver_major=
set tomcat_ver_minor=
if not exist "%file%" (
  echo Error: wrong parameter in checkJava17tomcat2 call
  goto :eof
)
findstr /C:"Apache Tomcat Version " "%file%" > "%TALEND_HOME%\utils\out.txt"
"%TALEND_HOME%\utils\sed" -e "s/.*Version //" "%TALEND_HOME%\utils\out.txt" > "%TALEND_HOME%\utils\out1.txt"

"%TALEND_HOME%\utils\sed" -e "s/\..*//" "%TALEND_HOME%\utils\out1.txt" > "%TALEND_HOME%\utils\out_major.txt"
set /p tomcat_ver_major=<"%TALEND_HOME%\utils\out_major.txt"
if %tomcat_ver_major% LSS 9 goto :errorJava17wrongversion

rem If tomcat version is above 9, for example if it is version 10, then it is fine
if %tomcat_ver_major% GTR 9 goto :eof

rem Checking the minor version
"%TALEND_HOME%\utils\sed" -e "s/^[0-9]\.[ 0-9]\.//" "%TALEND_HOME%\utils\out1.txt" > "%TALEND_HOME%\utils\out_minor.txt"
set /p tomcat_ver_minor=<"%TALEND_HOME%\utils\out_minor.txt"
if %tomcat_ver_major% EQU 9 ( 
  if %tomcat_ver_minor% LSS 82 goto :errorJava17wrongversion
)

goto :eof

:checkJava17dataprep
if not exist "%TALEND_HOME%\dataprep\start.bat" goto :eof
set dataprep_ver_major=
set dataprep_ver_minor=
dir "%TALEND_HOME%\dataprep\lib\dataprep-core-*.jar" /b | findstr /V "actions" | "%TALEND_HOME%\utils\sed" -e "s/dataprep-core-//" | "%TALEND_HOME%\utils\sed" -e "s/\.jar//" > "%TALEND_HOME%\utils\out.txt"
for %%i in ("%TALEND_HOME%\utils\out.txt") do set filesize=%%~zi
if %filesize% EQU 0 goto :eof
"%TALEND_HOME%\utils\sed" -e "s/\..*//" "%TALEND_HOME%\utils\out.txt"      > "%TALEND_HOME%\utils\out_major.txt"
"%TALEND_HOME%\utils\sed" -e "s/^[^\.]*\.//" "%TALEND_HOME%\utils\out.txt" > "%TALEND_HOME%\utils\out1.txt"
"%TALEND_HOME%\utils\sed" -e "s/\..*//" "%TALEND_HOME%\utils\out1.txt"     > "%TALEND_HOME%\utils\out_minor.txt"
for %%i in ("%TALEND_HOME%\utils\out_major.txt") do set filesize=%%~zi
if %filesize% EQU 0 goto :eof
for %%i in ("%TALEND_HOME%\utils\out_minor.txt") do set filesize=%%~zi
if %filesize% EQU 0 goto :eof

set /p dataprep_ver_major=<%TALEND_HOME%\utils\out_major.txt
set /p dataprep_ver_minor=<%TALEND_HOME%\utils\out_minor.txt

if %dataprep_ver_major% LSS 5 goto :errorJava17wrongversion

if %dataprep_ver_major% EQU 5 (
  if %dataprep_ver_minor% LSS 14 goto :errorJava17wrongversion
)

goto :eof

:checkJava17runtime
rem Runtime version is checked indirectly with the version of org/hibernate/hibernate-core dependency.
rem For 8.0.1.R2023-10-RT it should be 5.6.7.Final (this script checks only 5.6 or above)

if not exist "%TALEND_HOME%\runtime\version.txt" goto :eof
dir /b "%TALEND_HOME%\runtime\system\org\hibernate\hibernate-core" > "%TALEND_HOME%\utils\out.txt"
for %%i in ("%TALEND_HOME%\utils\out.txt") do set filesize=%%~zi
if %filesize% EQU 0 (
  call :errorJava17wrongversion
  goto :eof
)
set hibernate_ver_major=
set hibernate_ver_minor=

"%TALEND_HOME%\utils\sed" -e "s/\..*//" "%TALEND_HOME%\utils\out.txt"      > "%TALEND_HOME%\utils\out_major.txt"
"%TALEND_HOME%\utils\sed" -e "s/^[^\.]*\.//" "%TALEND_HOME%\utils\out.txt" > "%TALEND_HOME%\utils\out1.txt"
"%TALEND_HOME%\utils\sed" -e "s/\..*//" "%TALEND_HOME%\utils\out1.txt"     > "%TALEND_HOME%\utils\out_minor.txt"
for %%i in ("%TALEND_HOME%\utils\out_major.txt") do set filesize=%%~zi
if %filesize% EQU 0 goto :eof
for %%i in ("%TALEND_HOME%\utils\out_minor.txt") do set filesize=%%~zi
if %filesize% EQU 0 goto :eof

set /p hibernate_ver_major=<%TALEND_HOME%\utils\out_major.txt
set /p hibernate_ver_minor=<%TALEND_HOME%\utils\out_minor.txt

if %hibernate_ver_major% LSS 5 goto :errorJava17wrongversion

if %hibernate_ver_major% EQU 5 (
  if %hibernate_ver_minor% LSS 6 goto :errorJava17wrongversion
) 

goto :eof

:errorJava17wrongversion
if defined StopJavaUpgrade goto :eof
echo Error: target Java is Java 17, but the Talend software version is older than 8.0.1 R2023-10.
echo        Setting up Java 17 for that version will make the system unusable.
echo Java upgrade is stopped
set StopJavaUpgrade=1
exit /b 1 
goto :eof

:checkService
set SRV_NAME=%1
set VAR_NAME=%2
set %VAR_NAME%=
sc query %SRV_NAME% | findstr /C:"%SRV_NAME%" >"%TALEND_HOME%\utils\1.txt"
set /p %VAR_NAME%=<"%TALEND_HOME%\utils\1.txt"
del /q "%TALEND_HOME%\utils\1.txt"
goto :eof

:UpdateJobserver
cd "%TALEND_HOME%\jobserver\agent"
"%TALEND_HOME%\utils\sed" -e "s|^set MY_JAVA=.*|set MY_JAVA=\"%JAVA_HOME_MOD%\"|" start_rs.bat > start_rs.bat.new
call ::RenameFile start_rs.bat start_rs.bat.new

"%TALEND_HOME%\utils\sed" -e "s|^set MY_JAVA=.*|set MY_JAVA=\"%JAVA_HOME_MOD%\"|" stop_rs.bat > stop_rs.bat.new
call ::RenameFile stop_rs.bat stop_rs.bat.new
goto :eof
